ArbDebugApiServer

Trait ArbDebugApiServer 

pub trait ArbDebugApiServer:
    Sized
    + Send
    + Sync
    + 'static {
    // Required methods
    fn pricing_model<'life0, 'async_trait>(
        &'life0 self,
        start: u64,
        end: u64,
    ) -> Pin<Box<dyn Future<Output = RpcResult<PricingModelHistory>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn timeout_queue_history<'life0, 'async_trait>(
        &'life0 self,
        start: u64,
        end: u64,
    ) -> Pin<Box<dyn Future<Output = RpcResult<TimeoutQueueHistory>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn timeout_queue<'life0, 'async_trait>(
        &'life0 self,
        block_num: u64,
    ) -> Pin<Box<dyn Future<Output = RpcResult<TimeoutQueue>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;

    // Provided method
    fn into_rpc(self) -> RpcModule<Self> { ... }
}
Server trait implementation for the ArbDebugApi RPC API.

Required Methods

fn pricing_model<'life0, 'async_trait>( &'life0 self, start: u64, end: u64, ) -> Pin<Box<dyn Future<Output = RpcResult<PricingModelHistory>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn timeout_queue_history<'life0, 'async_trait>( &'life0 self, start: u64, end: u64, ) -> Pin<Box<dyn Future<Output = RpcResult<TimeoutQueueHistory>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn timeout_queue<'life0, 'async_trait>( &'life0 self, block_num: u64, ) -> Pin<Box<dyn Future<Output = RpcResult<TimeoutQueue>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Provided Methods

fn into_rpc(self) -> RpcModule<Self>

Collects all the methods and subscriptions defined in the trait and adds them into a single RpcModule.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<Provider> ArbDebugApiServer for ArbDebugHandler<Provider>
where Provider: StateProviderFactory + BlockReaderIdExt + ReceiptProvider + Clone + Send + Sync + 'static,