ArbTimeboostAuctioneerApiServer

Trait ArbTimeboostAuctioneerApiServer 

pub trait ArbTimeboostAuctioneerApiServer:
    Sized
    + Send
    + Sync
    + 'static {
    // Required method
    fn submit_auction_resolution_transaction<'life0, 'async_trait>(
        &'life0 self,
        raw_tx: Bytes,
    ) -> Pin<Box<dyn Future<Output = RpcResult<B256>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;

    // Provided method
    fn into_rpc(self) -> RpcModule<Self> { ... }
}
Server trait implementation for the ArbTimeboostAuctioneerApi RPC API.

Required Methods

fn submit_auction_resolution_transaction<'life0, 'async_trait>( &'life0 self, raw_tx: Bytes, ) -> Pin<Box<dyn Future<Output = RpcResult<B256>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Submit the winning auction resolution tx. The transaction encodes round + winner + bids. Only the configured auctioneer may call this.

Provided Methods

fn into_rpc(self) -> RpcModule<Self>

Collects all the methods and subscriptions defined in the trait and adds them into a single RpcModule.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors