ArbTraceApiServer

Trait ArbTraceApiServer 

pub trait ArbTraceApiServer:
    Sized
    + Send
    + Sync
    + 'static {
    // Required methods
    fn call<'life0, 'async_trait>(
        &'life0 self,
        call_args: Box<RawValue>,
        trace_types: Box<RawValue>,
        block_num_or_hash: Box<RawValue>,
    ) -> Pin<Box<dyn Future<Output = RpcResult<JsonValue>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn call_many<'life0, 'async_trait>(
        &'life0 self,
        calls: Box<RawValue>,
        block_num_or_hash: Box<RawValue>,
    ) -> Pin<Box<dyn Future<Output = RpcResult<JsonValue>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn replay_block_transactions<'life0, 'async_trait>(
        &'life0 self,
        block_num_or_hash: Box<RawValue>,
        trace_types: Box<RawValue>,
    ) -> Pin<Box<dyn Future<Output = RpcResult<JsonValue>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn replay_transaction<'life0, 'async_trait>(
        &'life0 self,
        tx_hash: Box<RawValue>,
        trace_types: Box<RawValue>,
    ) -> Pin<Box<dyn Future<Output = RpcResult<JsonValue>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn transaction<'life0, 'async_trait>(
        &'life0 self,
        tx_hash: Box<RawValue>,
    ) -> Pin<Box<dyn Future<Output = RpcResult<JsonValue>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn get<'life0, 'async_trait>(
        &'life0 self,
        tx_hash: Box<RawValue>,
        path: Box<RawValue>,
    ) -> Pin<Box<dyn Future<Output = RpcResult<JsonValue>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn block<'life0, 'async_trait>(
        &'life0 self,
        block_num_or_hash: Box<RawValue>,
    ) -> Pin<Box<dyn Future<Output = RpcResult<JsonValue>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn filter<'life0, 'async_trait>(
        &'life0 self,
        filter: Box<RawValue>,
    ) -> Pin<Box<dyn Future<Output = RpcResult<JsonValue>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;

    // Provided method
    fn into_rpc(self) -> RpcModule<Self> { ... }
}
Server trait implementation for the ArbTraceApi RPC API.

Required Methods

fn call<'life0, 'async_trait>( &'life0 self, call_args: Box<RawValue>, trace_types: Box<RawValue>, block_num_or_hash: Box<RawValue>, ) -> Pin<Box<dyn Future<Output = RpcResult<JsonValue>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn call_many<'life0, 'async_trait>( &'life0 self, calls: Box<RawValue>, block_num_or_hash: Box<RawValue>, ) -> Pin<Box<dyn Future<Output = RpcResult<JsonValue>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn replay_block_transactions<'life0, 'async_trait>( &'life0 self, block_num_or_hash: Box<RawValue>, trace_types: Box<RawValue>, ) -> Pin<Box<dyn Future<Output = RpcResult<JsonValue>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn replay_transaction<'life0, 'async_trait>( &'life0 self, tx_hash: Box<RawValue>, trace_types: Box<RawValue>, ) -> Pin<Box<dyn Future<Output = RpcResult<JsonValue>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn transaction<'life0, 'async_trait>( &'life0 self, tx_hash: Box<RawValue>, ) -> Pin<Box<dyn Future<Output = RpcResult<JsonValue>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn get<'life0, 'async_trait>( &'life0 self, tx_hash: Box<RawValue>, path: Box<RawValue>, ) -> Pin<Box<dyn Future<Output = RpcResult<JsonValue>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn block<'life0, 'async_trait>( &'life0 self, block_num_or_hash: Box<RawValue>, ) -> Pin<Box<dyn Future<Output = RpcResult<JsonValue>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn filter<'life0, 'async_trait>( &'life0 self, filter: Box<RawValue>, ) -> Pin<Box<dyn Future<Output = RpcResult<JsonValue>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Provided Methods

fn into_rpc(self) -> RpcModule<Self>

Collects all the methods and subscriptions defined in the trait and adds them into a single RpcModule.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors