ConditionalTxApiServer

Trait ConditionalTxApiServer 

pub trait ConditionalTxApiServer:
    Sized
    + Send
    + Sync
    + 'static {
    // Required method
    fn send_raw_transaction_conditional<'life0, 'async_trait>(
        &'life0 self,
        raw_tx: Bytes,
        options: ConditionalOptions,
    ) -> Pin<Box<dyn Future<Output = RpcResult<B256>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;

    // Provided method
    fn into_rpc(self) -> RpcModule<Self> { ... }
}
Server trait implementation for the ConditionalTxApi RPC API.

Required Methods

fn send_raw_transaction_conditional<'life0, 'async_trait>( &'life0 self, raw_tx: Bytes, options: ConditionalOptions, ) -> Pin<Box<dyn Future<Output = RpcResult<B256>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Submit a signed raw tx with attached predicates. Returns the tx hash on acceptance; error on predicate failure or pool rejection.

Provided Methods

fn into_rpc(self) -> RpcModule<Self>

Collects all the methods and subscriptions defined in the trait and adds them into a single RpcModule.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors