pub fn cache_trace(tx_hash: B256, records: Vec<HostioTraceInfo>)Expand description
Store the Stylus host-I/O records for a tx-hash. Called by the block producer after executing a tx with the trace buffer active.
pub fn cache_trace(tx_hash: B256, records: Vec<HostioTraceInfo>)Store the Stylus host-I/O records for a tx-hash. Called by the block producer after executing a tx with the trace buffer active.